Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/server.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/build
diff options
context:
space:
mode:
authorDaniel Calviño Sánchez <danxuliu@gmail.com>2022-07-06 18:36:30 +0300
committerDaniel Calviño Sánchez <danxuliu@gmail.com>2022-07-06 18:36:30 +0300
commit860f67ae8af3ffeb891c5cda4b4a463487328858 (patch)
tree74a300fd180fdb8d9239e0b35ca8e010c401778f /build
parent0cbea21e8635acbd6e2ae052dc92b5c173d67879 (diff)
Fix branch selection in stable24fix-branch-selection-in-stable24
Signed-off-by: Joas Schilling <coding@schilljs.com> Signed-off-by: Daniel Calviño Sánchez <danxuliu@gmail.com>
Diffstat (limited to 'build')
-rwxr-xr-xbuild/update-apps.sh8
-rwxr-xr-xbuild/update.sh6
2 files changed, 7 insertions, 7 deletions
diff --git a/build/update-apps.sh b/build/update-apps.sh
index e4611a79aff..b3853aa0eac 100755
--- a/build/update-apps.sh
+++ b/build/update-apps.sh
@@ -1,14 +1,14 @@
#!/bin/bash
# Update Nextcloud apps from latest git master
# For local development environment
# Use from Nextcloud server folder with `./build/update-apps.sh`
#
# It automatically:
# - goes through all apps which are not shipped via server
# - shows the app name in bold and uses whitespace for separation
# - changes to master and pulls quietly
# - shows the 3 most recent commits for context
# - removes branches merged into master
# - … could even do the build steps if they are consistent for the apps (like `make`)
-find apps* -maxdepth 2 -name .git -exec sh -c 'cd {}/../ && printf "\n\033[1m${PWD##*/}\033[0m\n" && git checkout master && git pull --quiet -p && git --no-pager log -3 --pretty=format:"%h %Cblue%ar%x09%an %Creset%s" && printf "\n" && git branch --merged master | grep -v "master$" | xargs git branch -d && cd ..' \;
+find apps* -maxdepth 2 -name .git -exec sh -c 'cd {}/../ && printf "\n\033[1m${PWD##*/}\033[0m\n" && git checkout stable24 && git pull --quiet -p && git --no-pager log -3 --pretty=format:"%h %Cblue%ar%x09%an %Creset%s" && printf "\n" && git branch --merged stable24 | grep -v "stable24$" | xargs git branch -d && cd ..' \;
@@ -1,14 +1,14 @@
#!/bin/bash
-# Update Nextcloud apps from latest git master
+# Update Nextcloud apps from latest git stable24
# For local development environment
# Use from Nextcloud server folder with `./build/update-apps.sh`
@@ -1,14 +1,14 @@
# - goes through all apps which are not shipped via server
# - shows the app name in bold and uses whitespace for separation
-# - changes to master and pulls quietly
+# - changes to stable24 and pulls quietly
# - shows the 3 most recent commits for context
@@ -1,14 +1,14 @@
# - shows the 3 most recent commits for context
-# - removes branches merged into master
+# - removes branches merged into stable24
# - … could even do the build steps if they are consistent for the apps (like `make`)
diff --git a/build/update.sh b/build/update.sh
index 3a3d2eac5dc..d83e1964da3 100755
--- a/build/update.sh
+++ b/build/update.sh
@@ -1,15 +1,15 @@
#!/bin/bash
# Update Nextcloud server and apps from latest git master
# For local development environment
# Use from Nextcloud server folder with `./build/update.sh`
# Update server
printf "\n\033[1m${PWD##*/}\033[0m\n"
-git checkout master
+git checkout stable24
git pull --quiet -p
git --no-pager log -3 --pretty=format:"%h %Cblue%ar%x09%an %Creset%s"
printf "\n"
-git branch --merged master | grep -v "master$" | xargs git branch -d
+git branch --merged stable24 | grep -v "stable24$" | xargs git branch -d
git submodule update --init
# Update apps
@@ -1,15 +1,15 @@
#!/bin/bash
-# Update Nextcloud server and apps from latest git master
+# Update Nextcloud server and apps from latest git stable24
# For local development environment
# Use from Nextcloud server folder with `./build/update.sh`